@@ -10,7 +10,8 @@ use warnings;
 
 # base class for nodes, relationships, indexes...
 BEGIN {
-  $REST::Neo4p::Entity::VERSION = '0.3010';
+  $REST::Neo4p::Entity::VERSION = '0.3011';
+  $REST::Neo4p::Entity::VERSION = '0.3011';
 }
 
 our $ENTITY_TABLE = {};
@@ -42,7 +43,7 @@ sub new {
     $e->rethrow;
   }
   elsif ($e = Exception::Class->caught()) {
-    ref $e ? $e->rethrow : die $e;
+    (ref $e && $e->can("rethrow")) ? $e->rethrow : die $e;
   }
 
   $decoded_resp->{self} ||= $agent->location if ref $decoded_resp;
@@ -136,7 +137,7 @@ sub remove {
     1;
   }
   elsif ($e = Exception::Class->caught()) {
-    ref $e ? $e->rethrow : die $e;
+    (ref $e && $e->can("rethrow")) ? $e->rethrow : die $e;
   }
   $self->_deregister;
   return 1;
@@ -166,7 +167,7 @@ sub set_property {
       $e->rethrow;
     }
     elsif ($e = Exception::Class->caught()) {
-      ref $e ? $e->rethrow : die $e;
+      (ref $e && $e->can("rethrow")) ? $e->rethrow : die $e;
     }
   }
   # create accessors
@@ -199,7 +200,7 @@ sub get_property {
       push @ret, undef;
     }
     elsif ( $e = Exception::Class->caught()) {
-      ref $e ? $e->rethrow : die $e;
+      (ref $e && $e->can("rethrow")) ? $e->rethrow : die $e;
     }
     else {
       _unescape($decoded_resp);
@@ -229,7 +230,7 @@ sub get_properties {
     return;
   }
   elsif ($e = Exception::Class->caught()) {
-    ref $e ? $e->rethrow : die $e;
+    (ref $e && $e->can("rethrow")) ? $e->rethrow : die $e;
   }
   _unescape($decoded_resp);
   return $decoded_resp;
@@ -274,7 +275,7 @@ sub remove_property {
       $e->rethrow;
     }
     elsif ($e = Exception::Class->caught()) {
-      ref $e ? $e->rethrow : die $e;
+      (ref $e && $e->can("rethrow")) ? $e->rethrow : die $e;
     }
   }
   return $self;
@@ -360,7 +361,7 @@ sub _entity_by_id {
 	$e->rethrow;
       }
       elsif ($e = Exception::Class->caught()) {
-	ref $e ? $e->rethrow : die $e;
+	(ref $e && $e->can("rethrow")) ? $e->rethrow : die $e;
       }
     }
     $new = ref($decoded_resp) ? $class->new_from_json_response($decoded_resp) :
@@ -435,7 +436,8 @@ use strict;
 use warnings;
 no warnings qw/once/;
 BEGIN {
-  $REST::Neo4p::Simple::VERSION = '0.3010';
+  $REST::Neo4p::Simple::VERSION = '0.3011';
+  $REST::Neo4p::Simple::VERSION = '0.3011';
 }
 
 sub new { $_[1] }
