@@ -8,7 +8,8 @@ use strict;
 use warnings;
 
 BEGIN {
-  $REST::Neo4p::Index::VERSION = '0.3010';
+  $REST::Neo4p::Index::VERSION = '0.3011';
+  $REST::Neo4p::Index::VERSION = '0.3011';
 }
 
 my $unsafe = "^A-Za-z0-9\-\._\ ~";
@@ -95,7 +96,7 @@ sub add_entry {
       $e->rethrow;
     }
     elsif ($e = Exception::Class->caught()) {
-      ref $e ? $e->rethrow : die $e;
+      (ref $e && $e->can("rethrow")) ? $e->rethrow : die $e;
     }
   }
   return 1;
@@ -179,7 +180,7 @@ sub find_entries {
       $e->rethrow;
     }
     elsif ($e = Exception::Class->caught) {
-      ref $e ? $e->rethrow : die $e;
+      (ref $e && $e->can("rethrow")) ? $e->rethrow : die $e;
     }
   }
   my @ret; 
@@ -236,7 +237,7 @@ sub create_unique_node {
     }
   }
   elsif ($e = Exception::Class->caught) {
-    ref $e ? $e->rethrow : die $e;
+    (ref $e && $e->can("rethrow")) ? $e->rethrow : die $e;
   }
   return REST::Neo4p::Node->new_from_json_response($decoded_resp);
 }
@@ -287,7 +288,7 @@ sub create_unique_relationship {
     }
   }
   elsif ($e = Exception::Class->caught) {
-    ref $e ? $e->rethrow : die $e;
+    (ref $e && $e->can("rethrow")) ? $e->rethrow : die $e;
   }
   return REST::Neo4p::Relationship->new_from_json_response($decoded_resp);
 }
